@@ -1,22 +1,28 @@
-/*  $Id: api.c 3193 2007-05-31 23:17:05Z rra $
-**
-**  Entry points for the remctl library API.
-**
-**  All of the high-level entry points for the remctl library API, defined in
-**  remctl.h, are found here.  The detailed implementation of these APIs are
-**  in other source files.
-**
-**  Written by Russ Allbery <rra@stanford.edu>
-**  Based on work by Anton Ushakov
-**  Copyright 2002, 2003, 2004, 2005, 2006, 2007
-**      Board of Trustees, Leland Stanford Jr. University
-**
-**  See README for licensing terms.
-*/
+/* $Id: api.c 4026 2008-04-04 23:37:08Z rra $
+ *
+ * Entry points for the remctl library API.
+ *
+ * All of the high-level entry points for the remctl library API, defined in
+ * remctl.h, are found here.  The detailed implementation of these APIs are
+ * in other source files.
+ *
+ * All public functions defined here should use int to return boolean values.
+ * We don't try to set up the portability glue to use bool in our public
+ * headers.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Based on work by Anton Ushakov
+ * Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 #include <portable/gssapi.h>
+#include <portable/socket.h>
+#include <portable/uio.h>
 
 #include <errno.h>
 
@@ -26,11 +32,11 @@
 
 
 /*
-**  Handle an internal failure for the simplified interface.  We try to grab
-**  the remctl error and put it into the error field in the remctl result, but
-**  if that fails, we free the remctl result and return NULL to indicate a
-**  fatal error.
-*/
+ * Handle an internal failure for the simplified interface.  We try to grab
+ * the remctl error and put it into the error field in the remctl result, but
+ * if that fails, we free the remctl result and return NULL to indicate a
+ * fatal error.
+ */
 static struct remctl_result *
 internal_fail(struct remctl *r, struct remctl_result *result)
 {
@@ -55,13 +61,13 @@ internal_fail(struct remctl *r, struct remctl_result *result)
 
 
 /*
-**  Given a struct remctl_result into which we're accumulating output and a
-**  struct remctl_output that contains a fragment of output, append the output
-**  to the appropriate slot in the result.  This is not particularly
-**  efficient.  Returns false if something fails and tries to set
-**  result->error; if we can't even do that, make sure it's set to NULL.
-*/
-static int
+ * Given a struct remctl_result into which we're accumulating output and a
+ * struct remctl_output that contains a fragment of output, append the output
+ * to the appropriate slot in the result.  This is not particularly efficient.
+ * Returns false if something fails and tries to set result->error; if we
+ * can't even do that, make sure it's set to NULL.
+ */
+static bool
 internal_output_append(struct remctl_result *result,
                        struct remctl_output *output)
 {
@@ -86,12 +92,12 @@ internal_output_append(struct remctl_result *result,
                           output->stream);
         if (status < 0)
             result->error = NULL;
-        return 0;
+        return false;
     } else {
         if (result->error != NULL)
             free(result->error);
         result->error = strdup("internal error: bad output type");
-        return 0;
+        return false;
     }
 
     /* We've done our setup, so now we can do the actual manipulation. */
@@ -110,7 +116,7 @@ internal_output_append(struct remctl_result *result,
         if (result->error != NULL)
             free(result->error);
         result->error = strdup("cannot allocate memory");
-        return 0;
+        return false;
     }
     *buffer = newbuf;
     if (length != NULL)
@@ -118,16 +124,16 @@ internal_output_append(struct remctl_result *result,
     memcpy(*buffer + oldlen, output->data, output->length);
     if (output->type == REMCTL_OUT_ERROR)
         (*buffer)[newlen - 1] = '\0';
-    return 1;
+    return true;
 }
 
 
 /*
-**  The simplified interface.  Given a host, a port, and a command (as a
-**  null-terminated argv-style vector), run the command on that host and port
-**  and return a struct remctl_result.  The result should be freed with
-**  remctl_result_free.
-*/
+ * The simplified interface.  Given a host, a port, and a command (as a
+ * null-terminated argv-style vector), run the command on that host and port
+ * and return a struct remctl_result.  The result should be freed with
+ * remctl_result_free.
+ */
 struct remctl_result *
 remctl(const char *host, unsigned short port, const char *principal,
        const char **command)
@@ -175,8 +181,8 @@ remctl(const char *host, unsigned short port, const char *principal,
 
 
 /*
-**  Free a struct remctl_result returned by remctl.
-*/
+ * Free a struct remctl_result returned by remctl.
+ */
 void
 remctl_result_free(struct remctl_result *result)
 {
@@ -193,15 +199,18 @@ remctl_result_free(struct remctl_result *result)
 
 
 /*
-**  Create a new remctl object.  Don't attempt to connect here; we do that
-**  separately so that we can still use the object to store error messages
-**  from connection failures.  Return NULL on memory allocation failures.
-*/
+ * Create a new remctl object.  Don't attempt to connect here; we do that
+ * separately so that we can still use the object to store error messages
+ * from connection failures.  Return NULL on memory allocation failures or
+ * socket initialization failures (Windows).
+ */
 struct remctl *
 remctl_new(void)
 {
     struct remctl *r;
 
+    if (!socket_init())
+        return NULL;
     r = calloc(1, sizeof(struct remctl));
     if (r == NULL)
         return NULL;
@@ -216,15 +225,15 @@ remctl_new(void)
 
 
 /*
-**  Open a new persistant remctl connection to a server, given the host, port,
-**  and principal.  Returns true on success and false on failure.
-*/
+ * Open a new persistant remctl connection to a server, given the host, port,
+ * and principal.  Returns true on success and false on failure.
+ */
 int
 remctl_open(struct remctl *r, const char *host, unsigned short port,
             const char *principal)
 {
     if (r->fd != -1)
-        close(r->fd);
+        socket_close(r->fd);
     if (r->error != NULL) {
         free(r->error);
         r->error = NULL;
@@ -242,8 +251,8 @@ remctl_open(struct remctl *r, const char *host, unsigned short port,
 
 
 /*
-**  Close a persistant remctl connection.
-*/
+ * Close a persistant remctl connection.
+ */
 void
 remctl_close(struct remctl *r)
 {
@@ -251,25 +260,26 @@ remctl_close(struct remctl *r)
         if (r->protocol > 1 && r->fd != -1)
             internal_v2_quit(r);
         if (r->fd != -1)
-            close(r->fd);
+            socket_close(r->fd);
         if (r->error != NULL)
             free(r->error);
         if (r->output != NULL)
             free(r->output);
         free(r);
     }
+    socket_shutdown();
 }
 
 
 /*
-**  Send a complete remote command.  Returns true on success, false on
-**  failure.  On failure, use remctl_error to get the error.  command is a
-**  NULL-terminated array of nul-terminated strings.  finished is a boolean
-**  flag that should be false when the command is not yet complete and true
-**  when this is the final (or only) segment.
-**
-**  Implement in terms of remctl_commandv.
-*/
+ * Send a complete remote command.  Returns true on success, false on failure.
+ * On failure, use remctl_error to get the error.  command is a
+ * NULL-terminated array of nul-terminated strings.  finished is a boolean
+ * flag that should be false when the command is not yet complete and true
+ * when this is the final (or only) segment.
+ *
+ * Implement in terms of remctl_commandv.
+ */
 int
 remctl_command(struct remctl *r, const char **command)
 {
@@ -281,7 +291,7 @@ remctl_command(struct remctl *r, const char **command)
         ;
     vector = malloc(sizeof(struct iovec) * count);
     if (vector == NULL) {
-        internal_set_error(r, "Cannot allocate memory: %s", strerror(errno));
+        internal_set_error(r, "cannot allocate memory: %s", strerror(errno));
         return 0;
     }
     for (i = 0; i < count; i++) {
@@ -295,15 +305,15 @@ remctl_command(struct remctl *r, const char **command)
 
 
 /*
-**  Same as remctl_command, but take the command as an array of struct iovecs
-**  instead.  Use this form for binary data.
-*/
+ * Same as remctl_command, but take the command as an array of struct iovecs
+ * instead.  Use this form for binary data.
+ */
 int
 remctl_commandv(struct remctl *r, const struct iovec *command, size_t count)
 {
     if (r->fd < 0) {
         if (r->host == NULL) {
-            internal_set_error(r, "No connection open");
+            internal_set_error(r, "no connection open");
             return 0;
         }
         if (!remctl_open(r, r->host, r->port, r->principal))
@@ -321,9 +331,9 @@ remctl_commandv(struct remctl *r, const struct iovec *command, size_t count)
 
 
 /*
-**  Helper function for remctl_output implementations.  Free and reset the
-**  elements of the output struct, but don't free the output struct itself.
-*/
+ * Helper function for remctl_output implementations.  Free and reset the
+ * elements of the output struct, but don't free the output struct itself.
+ */
 void
 internal_output_wipe(struct remctl_output *output)
 {
@@ -342,24 +352,24 @@ internal_output_wipe(struct remctl_output *output)
 
 
 /*
-**  Retrieve output from the remote server.  Each call to this function on the
-**  same connection invalidates the previous returned remctl_output struct.
-**
-**  This function will return zero or more REMCTL_OUT_OUTPUT types followed by
-**  a REMCTL_OUT_STATUS type, *or* a REMCTL_OUT_ERROR type.  In either case,
-**  any subsequent call before sending a new command will return
-**  REMCTL_OUT_DONE.  If the function returns NULL, an internal error
-**  occurred; call remctl_error to retrieve the error message.
-**
-**  The remctl_output struct should *not* be freed by the caller.  It will be
-**  invalidated after another call to remctl_output or to remctl_close on the
-**  same connection.
-*/
+ * Retrieve output from the remote server.  Each call to this function on the
+ * same connection invalidates the previous returned remctl_output struct.
+ *
+ * This function will return zero or more REMCTL_OUT_OUTPUT types followed by
+ * a REMCTL_OUT_STATUS type, *or* a REMCTL_OUT_ERROR type.  In either case,
+ * any subsequent call before sending a new command will return
+ * REMCTL_OUT_DONE.  If the function returns NULL, an internal error occurred;
+ * call remctl_error to retrieve the error message.
+ *
+ * The remctl_output struct should *not* be freed by the caller.  It will be
+ * invalidated after another call to remctl_output or to remctl_close on the
+ * same connection.
+ */
 struct remctl_output *
 remctl_output(struct remctl *r)
 {
     if (r->fd < 0 && (r->protocol != 1 || r->host == NULL)) {
-        internal_set_error(r, "No connection open");
+        internal_set_error(r, "no connection open");
         return NULL;
     }
     if (r->error != NULL) {
@@ -374,12 +384,12 @@ remctl_output(struct remctl *r)
 
 
 /*
-**  Returns the internal error message after a failure or "No error" if the
-**  last command completed successfully.  This should generally only be called
-**  after a failure.
-*/
+ * Returns the internal error message after a failure or "No error" if the
+ * last command completed successfully.  This should generally only be called
+ * after a failure.
+ */
 const char *
 remctl_error(struct remctl *r)
 {
-    return (r->error != NULL) ? r->error : "No error";
+    return (r->error != NULL) ? r->error : "no error";
 }
