@@ -1,21 +1,23 @@
-/*  $Id: error.c 2978 2007-02-11 03:37:08Z rra $
-**
-**  Error handling for the remctl client library.
-**
-**  A set of helper routines to do error handling inside the remctl client
-**  library.  These mostly involve setting the error parameter in the remctl
-**  struct to something appropriate so that the next call to remctl_error will
-**  return the appropriate details.
-**
-**  Written by Russ Allbery <rra@stanford.edu>
-**  Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
-**
-**  See README for licensing terms.
-*/
+/* $Id: error.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Error handling for the remctl client library.
+ *
+ * A set of helper routines to do error handling inside the remctl client
+ * library.  These mostly involve setting the error parameter in the remctl
+ * struct to something appropriate so that the next call to remctl_error will
+ * return the appropriate details.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006, 2007, 2008
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 #include <portable/gssapi.h>
+#include <portable/socket.h>
 
 #include <errno.h>
 
@@ -23,8 +25,8 @@
 #include <util/util.h>
 
 /*
-**  Internal function to set the error message, freeing an old error message
-**  if one is present.
+ * Internal function to set the error message, freeing an old error message if
+ * one is present.
 */
 void
 internal_set_error(struct remctl *r, const char *format, ...)
@@ -38,17 +40,19 @@ internal_set_error(struct remctl *r, const char *format, ...)
     status = vasprintf(&r->error, format, args);
     va_end(args);
 
-    /* If vasprintf fails, there isn't much we can do, but make sure that at
-       least the error is in a consistent state. */
+    /*
+     * If vasprintf fails, there isn't much we can do, but make sure that at
+     * least the error is in a consistent state.
+     */
     if (status < 0)
         r->error = NULL;
 }
 
 
 /*
-**  Internal function to set the remctl error message from a GSS-API error
-**  message.
-*/
+ * Internal function to set the remctl error message from a GSS-API error
+ * message.
+ */
 void
 internal_gssapi_error(struct remctl *r, const char *error, OM_uint32 major,
                       OM_uint32 minor)
@@ -60,10 +64,10 @@ internal_gssapi_error(struct remctl *r, const char *error, OM_uint32 major,
 
 
 /*
-**  Internal function to set the remctl error message from a token error.
-**  Handles the various token failure codes from the token_send and token_recv
-**  functions and their *_priv counterparts.
-*/
+ * Internal function to set the remctl error message from a token error.
+ * Handles the various token failure codes from the token_send and token_recv
+ * functions and their *_priv counterparts.
+ */
 void
 internal_token_error(struct remctl *r, const char *error, int status,
                      OM_uint32 major, OM_uint32 minor)
@@ -75,6 +79,10 @@ internal_token_error(struct remctl *r, const char *error, int status,
     case TOKEN_FAIL_SYSTEM:
         internal_set_error(r, "error %s: %s", error, strerror(errno));
         break;
+    case TOKEN_FAIL_SOCKET:
+        internal_set_error(r, "error %s: %s", error,
+                           socket_strerror(socket_errno));
+        break;
     case TOKEN_FAIL_INVALID:
         internal_set_error(r, "error %s: invalid token format", error);
         break;
