@@ -1,18 +1,22 @@
-/*  $Id: remctl.c 3527 2007-09-02 06:31:04Z rra $
-**
-**  The client for a service for remote execution of predefined commands.
-**  Access is authenticated via GSS-API Kerberos 5, authorized via ACL files.
-**
-**  Originally written by Anton Ushakov <antonu@stanford.edu>
-**  Extensive modifications by Russ Allbery <rra@stanford.edu>
-**  Copyright 2002, 2003, 2004, 2005, 2006, 2007
-**      Board of Trustees, Leland Stanford Jr. University
-**
-**  See README for licensing terms.
+/* $Id: remctl.c 4024 2008-04-03 04:35:29Z rra $
+ *
+ * remctl command-line client.
+ *
+ * This is a command-line driver for the libremctl library, which takes the
+ * command on the command line and prints out the results to standard output
+ * and standard error as appropriate.
+ *
+ * Originally written by Anton Ushakov
+ * Extensive modifications by Russ Allbery <rra@stanford.edu>
+ * Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
 */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
+#include <portable/getopt.h>
 #include <portable/socket.h>
 
 #include <ctype.h>
@@ -33,21 +37,8 @@ Options:\n\
 
 
 /*
-**  Lowercase a string in place.
-*/
-static void 
-lowercase(char *string)
-{
-    char *p;
-
-    for (p = string; *p != '\0'; p++)
-        *p = tolower(*p);
-}
-
-
-/*
-**  Display the usage message for remctl.
-*/
+ * Display the usage message for remctl.
+ */
 static void
 usage(int status)
 {
@@ -57,13 +48,13 @@ usage(int status)
 
 
 /*
-**  Get the responses back from the server, taking appropriate action on each
-**  one depending on its type.  Sets the errorcode parameter to the exit
-**  status of the remote command, or to 1 if the remote command failed with an
-**  error.  Returns true on success, false if some protocol-level error
-**  occurred when reading the responses.
-*/
-static int
+ * Get the responses back from the server, taking appropriate action on each
+ * one depending on its type.  Sets the errorcode parameter to the exit status
+ * of the remote command, or to 1 if the remote command failed with an error.
+ * Returns true on success, false if some protocol-level error occurred when
+ * reading the responses.
+ */
+static bool
 process_response(struct remctl *r, int *errorcode)
 {
     struct remctl_output *out;
@@ -86,10 +77,10 @@ process_response(struct remctl *r, int *errorcode)
             *errorcode = 255;
             fwrite(out->data, out->length, 1, stderr);
             fputc('\n', stderr);
-            return 1;
+            return true;
         case REMCTL_OUT_STATUS:
             *errorcode = out->status;
-            return 1;
+            return true;
         case REMCTL_OUT_DONE:
             break;
         }
@@ -97,16 +88,16 @@ process_response(struct remctl *r, int *errorcode)
     }
     if (out == NULL) {
         die("error reading from server: %s", remctl_error(r));
-        return 0;
+        return false;
     } else
-        return 1;
+        return true;
 }
 
 
 /*
-**  Main routine.  Parse the arguments, open the remctl connection, send the
-**  command, and then call process_response.
-*/
+ * Main routine.  Parse the arguments, open the remctl connection, send the
+ * command, and then call process_response.
+ */
 int
 main(int argc, char *argv[])
 {
@@ -120,12 +111,16 @@ main(int argc, char *argv[])
 
     /* Set up logging and identity. */
     message_program_name = "remctl";
+    if (!socket_init())
+        die("failed to initialize socket library");
 
-    /* Parse options.  The + tells GNU getopt to stop option parsing at the
-       first non-argument rather than proceeding on to find options anywhere.
-       Without this, it's hard to call remote programs that take options.
-       Non-GNU getopt will treat the + as a supported option, which is handled
-       below. */
+    /*
+     * Parse options.  The + tells GNU getopt to stop option parsing at the
+     * first non-argument rather than proceeding on to find options anywhere.
+     * Without this, it's hard to call remote programs that take options.
+     * Non-GNU getopt will treat the + as a supported option, which is handled
+     * below.
+     */
     while ((option = getopt(argc, argv, "+dhp:s:v")) != EOF) {
         switch (option) {
         case 'd':
@@ -159,21 +154,32 @@ main(int argc, char *argv[])
     argc--;
 
     /*
-     * If service_name isn't set, we use host/<server>.  However, if the
-     * server to which we're connecting is a DNS-load-balanced name, we have
-     * to be careful what principal name we use.  Canonicalize the name with
-     * DNS (usually meaning a forward and reverse lookup).
+     * If service_name isn't set, the remctl library uses host/<server>
+     * (host@<server> in GSS-API parlance).  However, if the server to which
+     * we're connecting is a DNS-load-balanced name, we have to be careful
+     * what principal name we use.
      *
-     * We then have to make sure that we connect to the same host that we're
-     * using for the principal name.  If we get a different answer each time
-     * we ask DNS (possible with DNS load balancing), we need to connect to
-     * the canonical name rather than the original name given on the command
-     * line.
+     * Ideally, we would let the GSS-API library handle this and choose
+     * whether to canonicalize the <server> in the principal name based on the
+     * krb5.conf rdns setting and similar configuration.  However, with DNS
+     * load balancing, this still may fail.  At the time of network
+     * connection, we will connect to whatever the name resolves to then.
+     * After we connect, we authenticate, and the GSS-API library will then
+     * separately canonicalize the hostname.  It could get a different answer
+     * than we got for our network connection, leading to an authentication
+     * failure.
+     *
+     * Therefore, if the principal isn't specified, we canonicalize the
+     * hostname to which we're connecting before we connect.  Then, the
+     * additional canonicalization possibly done by the GSS-API library should
+     * return the same results and be consistent.
      *
      * Note that this opens the possibility of a subtle attack through DNS
      * spoofing, since both the principal used and the host to which we're
-     * connecting can be changed by varying the DNS response.  Providing a
-     * service on the command-line will deactivate this behavior.
+     * connecting can be changed by varying the DNS response.
+     *
+     * If the principal is specified explicitly, assume the user knows what
+     * they're doing and don't do any of this.
      */
     if (service_name == NULL) {
         memset(&hints, 0, sizeof(hints));
@@ -183,11 +189,7 @@ main(int argc, char *argv[])
             die("cannot resolve host %s: %s", server_host,
                 gai_strerror(status));
         server_host = xstrdup(ai->ai_canonname);
-        service_name = xmalloc(strlen("host/") + strlen(ai->ai_canonname) + 1);
-        strcpy(service_name, "host/");
-        strcat(service_name, ai->ai_canonname);
         freeaddrinfo(ai);
-        lowercase(service_name);
     }
 
     /* Open connection. */
@@ -205,14 +207,6 @@ main(int argc, char *argv[])
 
     /* Shut down cleanly. */
     remctl_close(r);
+    socket_shutdown();
     return errorcode;
 }
-
-
-/*
-**  Local variables:
-**  mode: c
-**  c-basic-offset: 4
-**  indent-tabs-mode: nil
-**  end:
-*/
