@@ -1,11 +1,11 @@
-/*  $Id: gssapi.h 2978 2007-02-11 03:37:08Z rra $
-**
-**  Portability wrapper around <gssapi.h>.
-**
-**  This header tries to encapsulate the differences between the MIT and
-**  Heimdal GSS-API implementations and the differences between various
-**  versions.
-*/
+/* $Id: gssapi.h 4029 2008-04-04 23:59:22Z rra $
+ *
+ * Portability wrapper around <gssapi.h>.
+ *
+ * This header tries to encapsulate the differences between the MIT and
+ * Heimdal GSS-API implementations and the differences between various
+ * versions.
+ */
 
 #ifndef PORTABLE_GSSAPI_H
 #define PORTABLE_GSSAPI_H 1
@@ -21,6 +21,7 @@
 /* Handle compatibility to older versions of MIT Kerberos. */
 #ifndef HAVE_GSS_RFC_OIDS
 # define GSS_C_NT_USER_NAME gss_nt_user_name
+# define GSS_C_NT_HOSTBASED_SERVICE gss_nt_service_name
 #endif
 
 /* Heimdal provides a nice #define for this. */
