@@ -1,39 +1,34 @@
-/*  $Id: internal.h 3294 2007-07-06 09:17:59Z rra $
-**
-**  Internal support functions for the remctld daemon.
-**
-**  Written by Russ Allbery <rra@stanford.edu>
-**  Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
-**
-**  See README for licensing terms.
-*/
+/* $Id: internal.h 4030 2008-04-05 00:03:27Z rra $
+ *
+ * Internal support functions for the remctld daemon.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006, 2007, 2008
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #ifndef SERVER_INTERNAL_H
 #define SERVER_INTERNAL_H 1
 
 #include <config.h>
 #include <portable/gssapi.h>
+#include <portable/macros.h>
+#include <portable/stdbool.h>
 
 #include <util/util.h>
 
-/* BEGIN_DECLS is used at the beginning of declarations so that C++
-   compilers don't mangle their names.  END_DECLS is used at the end. */
-#undef BEGIN_DECLS
-#undef END_DECLS
-#ifdef __cplusplus
-# define BEGIN_DECLS    extern "C" {
-# define END_DECLS      }
-#else
-# define BEGIN_DECLS    /* empty */
-# define END_DECLS      /* empty */
-#endif
-
-/* Used as the default max buffer for the argv passed into the server, and for 
-   the return message from the server. */
+/*
+ * Used as the default max buffer for the argv passed into the server, and for 
+ * the return message from the server.
+ */
 #define MAXBUFFER       64000  
 
-/* The maximum size of argc passed to the server.  This is an arbitrary limit
-   to protect against memory-based denial of service attacks on the server. */
+/*
+ * The maximum size of argc passed to the server.  This is an arbitrary limit
+ * to protect against memory-based denial of service attacks on the server.
+ */
 #define MAXCMDARGS      (4 * 1024)
 
 BEGIN_DECLS
@@ -47,10 +42,10 @@ struct client {
     gss_ctx_id_t context;       /* GSS-API context. */
     char *user;                 /* Name of the client as a string. */
     OM_uint32 flags;            /* Connection flags. */
-    int keepalive;              /* Whether keep-alive was set. */
+    bool keepalive;             /* Whether keep-alive was set. */
     char *output;               /* Stores output to send to the client. */
     size_t outlen;              /* Length of output to send to client. */
-    int fatal;                  /* Whether a fatal error has occurred. */
+    bool fatal;                 /* Whether a fatal error has occurred. */
 };
 
 /* Holds the configuration for a single command. */
@@ -78,7 +73,7 @@ void server_log_command(struct vector *, struct confline *, const char *user);
 /* Configuration file functions. */
 struct config *server_config_load(const char *file);
 void server_config_free(struct config *);
-int server_config_acl_permit(struct confline *, const char *user);
+bool server_config_acl_permit(struct confline *, const char *user);
 
 /* Running commands. */
 void server_run_command(struct client *, struct config *, struct vector *);
@@ -87,16 +82,16 @@ void server_run_command(struct client *, struct config *, struct vector *);
 struct client *server_new_client(int fd, gss_cred_id_t creds);
 void server_free_client(struct client *);
 struct vector *server_parse_command(struct client *, const char *, size_t);
-int server_send_error(struct client *, enum error_codes, const char *);
+bool server_send_error(struct client *, enum error_codes, const char *);
 
 /* Protocol v1 functions. */
-int server_v1_send_output(struct client *, int status);
+bool server_v1_send_output(struct client *, int status);
 void server_v1_handle_commands(struct client *, struct config *);
 
 /* Protocol v2 functions. */
-int server_v2_send_output(struct client *, int stream);
-int server_v2_send_status(struct client *, int);
-int server_v2_send_error(struct client *, enum error_codes, const char *);
+bool server_v2_send_output(struct client *, int stream);
+bool server_v2_send_status(struct client *, int);
+bool server_v2_send_error(struct client *, enum error_codes, const char *);
 void server_v2_handle_commands(struct client *, struct config *);
 
 END_DECLS
