@@ -1,35 +1,34 @@
-/*  $Id: server-v1.c 2978 2007-02-11 03:37:08Z rra $
-**
-**  Protocol v1, server implementation.
-**
-**  This is the server implementation of the old v1 protocol, which doesn't
-**  support streaming, keep-alive, or many of the other features of the
-**  current protocol.
-**
-**  Written by Russ Allbery <rra@stanford.edu>
-**  Based on work by Anton Ushakov
-**  Copyright 2002, 2003, 2004, 2005, 2006, 2007
-**      Board of Trustees, Leland Stanford Jr. University
-**
-**  See README for licensing terms.
-*/
+/* $Id: server-v1.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Protocol v1, server implementation.
+ *
+ * This is the server implementation of the old v1 protocol, which doesn't
+ * support streaming, keep-alive, or many of the other features of the
+ * current protocol.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Based on work by Anton Ushakov
+ * Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 #include <portable/gssapi.h>
-
-#include <netinet/in.h>
+#include <portable/socket.h>
 
 #include <server/internal.h>
 #include <util/util.h>
 
 
 /*
-**  Given the client struct, a buffer of data to send, and the exit status of
-**  a command, send a protocol v1 output token back to the client.  Returns
-**  true on success and false on failure (and logs a message on failure).
-*/
-int
+ * Given the client struct, a buffer of data to send, and the exit status of a
+ * command, send a protocol v1 output token back to the client.  Returns true
+ * on success and false on failure (and logs a message on failure).
+ */
+bool
 server_v1_send_output(struct client *client, int exit_status)
 {
     gss_buffer_desc token;
@@ -57,17 +56,17 @@ server_v1_send_output(struct client *client, int exit_status)
     if (status != TOKEN_OK) {
         warn_token("sending output token", status, major, minor);
         free(token.value);
-        return 0;
+        return false;
     }
     free(token.value);
-    return 1;
+    return true;
 }
 
 
 /*
-**  Takes the client struct and the server configuration and handles a client
-**  request.  Reads a command from the client, checks the ACL, runs the
-**  command if appropriate, and sends any output back to the client.
+ * Takes the client struct and the server configuration and handles a client
+ * request.  Reads a command from the client, checks the ACL, runs the command
+ * if appropriate, and sends any output back to the client.
 */
 void
 server_v1_handle_commands(struct client *client, struct config *config)
@@ -98,15 +97,18 @@ server_v1_handle_commands(struct client *client, struct config *config)
         return;
     }
 
-    /* Do the shared parsing of the message.  This code is identical to the
-       code for v2 (v2 just pulls more data off the front of the token
-       first). */
+    /*
+     * Do the shared parsing of the message.  This code is identical to the
+     * code for v2 (v2 just pulls more data off the front of the token first).
+     */
     argv = server_parse_command(client, token.value, token.length);
     gss_release_buffer(&minor, &token);
     if (argv == NULL)
         return;
 
-    /* Check the ACL and existence of the command, run the command if
-       possible, and accumulate the output in the client struct. */
+    /*
+     * Check the ACL and existence of the command, run the command if
+     * possible, and accumulate the output in the client struct.
+     */
     server_run_command(client, config, argv);
 }
