@@ -1,34 +1,33 @@
-/*  $Id: server-v2.c 3140 2007-03-24 07:09:17Z rra $
-**
-**  Protocol v2, server implementation.
-**
-**  This is the server implementation of the new v2 protocol.
-**
-**  Written by Russ Allbery <rra@stanford.edu>
-**  Based on work by Anton Ushakov
-**  Copyright 2002, 2003, 2004, 2005, 2006, 2007
-**      Board of Trustees, Leland Stanford Jr. University
-**
-**  See README for licensing terms.
-*/
+/* $Id: server-v2.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Protocol v2, server implementation.
+ *
+ * This is the server implementation of the new v2 protocol.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Based on work by Anton Ushakov
+ * Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 #include <portable/gssapi.h>
-
-#include <netinet/in.h>
+#include <portable/socket.h>
 
 #include <server/internal.h>
 #include <util/util.h>
 
 
 /*
-**  Given the client struct and the stream number the data is from, send a
-**  protocol v2 output token to the client containing the data stored in the
-**  buffer in the client struct.  Returns true on success, false on failure
-**  (and logs a message on failure).
-*/
-int
+ * Given the client struct and the stream number the data is from, send a
+ * protocol v2 output token to the client containing the data stored in the
+ * buffer in the client struct.  Returns true on success, false on failure
+ * (and logs a message on failure).
+ */
+bool
 server_v2_send_output(struct client *client, int stream)
 {
     gss_buffer_desc token;
@@ -40,8 +39,10 @@ server_v2_send_output(struct client *client, int stream)
     token.length = 1 + 1 + 1 + 4 + client->outlen;
     token.value = xmalloc(token.length);
 
-    /* Fill in the header (version, type, stream, length, and data) and then
-       the data. */
+    /*
+     * Fill in the header (version, type, stream, length, and data) and then
+     * the data.
+     */
     p = token.value;
     *p = 2;
     p++;
@@ -60,20 +61,20 @@ server_v2_send_output(struct client *client, int stream)
     if (status != TOKEN_OK) {
         warn_token("sending output token", status, major, minor);
         free(token.value);
-        client->fatal = 1;
-        return 0;
+        client->fatal = true;
+        return false;
     }
     free(token.value);
-    return 1;
+    return true;
 }
 
 
 /*
-**  Given the client struct and the exit status, send a protocol v2 status
-**  token to the client.  Returns true on success, false on failure (and logs
-**  a message on failure).
-*/
-int
+ * Given the client struct and the exit status, send a protocol v2 status
+ * token to the client.  Returns true on success, false on failure (and logs a
+ * message on failure).
+ */
+bool
 server_v2_send_status(struct client *client, int exit_status)
 {
     gss_buffer_desc token;
@@ -93,19 +94,19 @@ server_v2_send_status(struct client *client, int exit_status)
                  TOKEN_DATA | TOKEN_PROTOCOL, &token, &major, &minor);
     if (status != TOKEN_OK) {
         warn_token("sending status token", status, major, minor);
-        client->fatal = 1;
-        return 0;
+        client->fatal = true;
+        return false;
     }
-    return 1;
+    return true;
 }
 
 
 /*
-**  Given the client struct, an error code, and an error message, send a
-**  protocol v2 error token to the client.  Returns true on success, false on
-**  failure (and logs a message on failure).
-*/
-int
+ * Given the client struct, an error code, and an error message, send a
+ * protocol v2 error token to the client.  Returns true on success, false on
+ * failure (and logs a message on failure).
+ */
+bool
 server_v2_send_error(struct client *client, enum error_codes code,
                      const char *message)
 {
@@ -136,21 +137,20 @@ server_v2_send_error(struct client *client, enum error_codes code,
     if (status != TOKEN_OK) {
         warn_token("sending error token", status, major, minor);
         free(token.value);
-        client->fatal = 1;
-        return 0;
+        client->fatal = true;
+        return false;
     }
     free(token.value);
-    return 1;
+    return true;
 }
 
 
 /*
-**  Given the client struct, send a protocol v2 version token to the client.
-**  This is the response to a higher version number than we understand.
-**  Returns true on success, false on failure (and logs a message on
-**  failure).
-*/
-static int
+ * Given the client struct, send a protocol v2 version token to the client.
+ * This is the response to a higher version number than we understand.
+ * Returns true on success, false on failure (and logs a message on failure).
+ */
+static bool
 server_v2_send_version(struct client *client)
 {
     gss_buffer_desc token;
@@ -170,19 +170,19 @@ server_v2_send_version(struct client *client)
                  TOKEN_DATA | TOKEN_PROTOCOL, &token, &major, &minor);
     if (status != TOKEN_OK) {
         warn_token("sending version token", status, major, minor);
-        client->fatal = 1;
-        return 0;
+        client->fatal = true;
+        return false;
     }
-    return 1;
+    return true;
 }
 
 
 /*
-**  Receive a new token from the client, handling reporting of errors.  Takes
-**  the client struct and a pointer to storage for the token.  Returns
-**  TOKEN_OK on success, TOKEN_FAIL_EOF if the other end has gone away, and a
-**  different error code on a recoverable error.
-*/
+ * Receive a new token from the client, handling reporting of errors.  Takes
+ * the client struct and a pointer to storage for the token.  Returns TOKEN_OK
+ * on success, TOKEN_FAIL_EOF if the other end has gone away, and a different
+ * error code on a recoverable error.
+ */
 static int
 server_v2_read_token(struct client *client, gss_buffer_t token)
 {
@@ -202,11 +202,11 @@ server_v2_read_token(struct client *client, gss_buffer_t token)
 
 
 /*
-**  Handles a single token from the client, responding or running a command as
-**  appropriate.  Returns true if we should continue, false if an error
-**  occurred or QUIT was received and we should stop processing tokens.
-*/
-static int
+ * Handles a single token from the client, responding or running a command as
+ * appropriate.  Returns true if we should continue, false if an error
+ * occurred or QUIT was received and we should stop processing tokens.
+ */
+static bool
 server_v2_handle_token(struct client *client, struct config *config,
                        gss_buffer_t token)
 {
@@ -216,12 +216,14 @@ server_v2_handle_token(struct client *client, struct config *config,
     char *buffer = NULL;
     int status;
     OM_uint32 minor;
-    int continued = 0;
+    bool continued = false;
 
-    /* Loop on tokens until we have a complete command, allowing for continued
-       commands.  We're going to accumulate the full command in buffer until
-       we've seen all of it.  If the command isn't continued, we can use the
-       token as the buffer. */
+    /*
+     * Loop on tokens until we have a complete command, allowing for continued
+     * commands.  We're going to accumulate the full command in buffer until
+     * we've seen all of it.  If the command isn't continued, we can use the
+     * token as the buffer.
+     */
     total = 0;
     do {
         p = token->value;
@@ -229,14 +231,14 @@ server_v2_handle_token(struct client *client, struct config *config,
             return server_v2_send_version(client);
         if (p[1] == MESSAGE_QUIT) {
             debug("quit received, closing connection");
-            return 0;
+            return false;
         } else if (p[1] != MESSAGE_COMMAND) {
             warn("unknown message type %d from client", (int) p[1]);
             return server_send_error(client, ERROR_UNKNOWN_MESSAGE,
                                      "Unknown message");
         }
         p += 2;
-        client->keepalive = p[0] ? 1 : 0;
+        client->keepalive = p[0] ? true : false;
 
         /* Check the data size. */
         if (token->length > TOKEN_MAX_DATA) {
@@ -254,9 +256,11 @@ server_v2_handle_token(struct client *client, struct config *config,
         }
         continued = (p[1] == 1 || p[1] == 2);
 
-        /* Read the token data.  If the command is continued *or* if buffer is
-           non-NULL (meaning the command was previously continued), we copy
-           the data into the buffer. */
+        /*
+         * Read the token data.  If the command is continued *or* if buffer is
+         * non-NULL (meaning the command was previously continued), we copy
+         * the data into the buffer.
+         */
         p += 2;
         length = token->length - (p - (char *) token->value);
         if (continued || buffer != NULL) {
@@ -268,24 +272,28 @@ server_v2_handle_token(struct client *client, struct config *config,
             total += length;
         }
 
-        /* If the command was continued, we have to read the next token.
-           Otherwise, if buffer is NULL (no continuation), we just use this
-           token as the complete buffer. */
+        /*
+         * If the command was continued, we have to read the next token.
+         * Otherwise, if buffer is NULL (no continuation), we just use this
+         * token as the complete buffer.
+         */
         if (continued) {
             gss_release_buffer(&minor, token);
             status = server_v2_read_token(client, token);
             if (status == TOKEN_FAIL_EOF)
-                return 0;
+                return false;
             else if (status != TOKEN_OK)
-                return 1;
+                return true;
         } else if (buffer == NULL) {
             buffer = p;
             total = length;
         }
     } while (continued);
 
-    /* Okay, we now have a complete command that was possibly spread over
-       multiple tokens.  Now we can parse it.  */
+    /*
+     * Okay, we now have a complete command that was possibly spread over
+     * multiple tokens.  Now we can parse it.
+     */
     argv = server_parse_command(client, buffer, total);
     if (argv == NULL)
         return !client->fatal;
@@ -297,11 +305,11 @@ server_v2_handle_token(struct client *client, struct config *config,
 
 
 /*
-**  Takes the client struct and the server configuration and handles client
-**  requests.  Reads messages from the client, checking commands against the
-**  ACLs and executing them when appropriate, until the connection is
-**  terminated.
-*/
+ * Takes the client struct and the server configuration and handles client
+ * requests.  Reads messages from the client, checking commands against the
+ * ACLs and executing them when appropriate, until the connection is
+ * terminated.
+ */
 void
 server_v2_handle_commands(struct client *client, struct config *config)
 {
