@@ -1,12 +1,15 @@
-/* $Id: api-t.c 3655 2007-11-09 08:20:55Z rra $ */
-/* Test suite for the high-level remctl library API. */
-
-/* Written by Russ Allbery <rra@stanford.edu>
-   Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
-   See README for licensing terms. */
+/* $Id: api-t.c 4026 2008-04-04 23:37:08Z rra $
+ *
+ * Test suite for the high-level remctl library API.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 
 #include <signal.h>
 #ifdef HAVE_SYS_SELECT_H
@@ -21,10 +24,13 @@
 #include <tests/libtest.h>
 #include <util/util.h>
 
-/* Takes the current test number, the principal, and the protocol version and
-   runs a set of tests.  Due to the compatibility layer, we should be able to
-   run the same commands regardless of the protocol (we're not testing any of
-   the v2-specific features here).  Returns the next test number. */
+
+/*
+ * Takes the current test number, the principal, and the protocol version and
+ * runs a set of tests.  Due to the compatibility layer, we should be able to
+ * run the same commands regardless of the protocol (we're not testing any of
+ * the v2-specific features here).  Returns the next test number.
+ */
 static int
 do_tests(int n, const char *principal, int protocol)
 {
@@ -38,14 +44,14 @@ do_tests(int n, const char *principal, int protocol)
     /* Open the connection. */
     r = remctl_new();
     ok(n++, r != NULL);
-    ok_string(n++, "No error", remctl_error(r));
+    ok_string(n++, "no error", remctl_error(r));
     r->protocol = protocol;
     ok(n++, remctl_open(r, "localhost", 14444, principal));
-    ok_string(n++, "No error", remctl_error(r));
+    ok_string(n++, "no error", remctl_error(r));
 
     /* Send a successful command. */
     ok(n++, remctl_command(r, test));
-    ok_string(n++, "No error", remctl_error(r));
+    ok_string(n++, "no error", remctl_error(r));
     output = remctl_output(r);
     ok(n++, output != NULL);
     ok_int(n++, REMCTL_OUT_OUTPUT, output->type);
@@ -65,7 +71,7 @@ do_tests(int n, const char *principal, int protocol)
     command[1].iov_base = (char *) "test";
     command[1].iov_len = 4;
     ok(n++, remctl_commandv(r, command, 2));
-    ok_string(n++, "No error", remctl_error(r));
+    ok_string(n++, "no error", remctl_error(r));
     output = remctl_output(r);
     ok(n++, output != NULL);
     ok_int(n++, REMCTL_OUT_OUTPUT, output->type);
@@ -82,7 +88,7 @@ do_tests(int n, const char *principal, int protocol)
 
     /* Send a failing command. */
     ok(n++, remctl_command(r, error));
-    ok_string(n++, "No error", remctl_error(r));
+    ok_string(n++, "no error", remctl_error(r));
     output = remctl_output(r);
     ok(n++, output != NULL);
     if (protocol == 1) {
@@ -109,7 +115,7 @@ do_tests(int n, const char *principal, int protocol)
 
     /* Send a command with no service. */
     ok(n++, remctl_command(r, no_service));
-    ok_string(n++, "No error", remctl_error(r));
+    ok_string(n++, "no error", remctl_error(r));
     output = remctl_output(r);
     ok(n++, output != NULL);
     ok_int(n++, REMCTL_OUT_OUTPUT, output->type);
@@ -131,6 +137,7 @@ do_tests(int n, const char *principal, int protocol)
     return n;
 }
 
+
 int
 main(void)
 {
@@ -155,10 +162,12 @@ main(void)
         n = do_tests(1, principal, 1);
         n = do_tests(n, principal, 2);
 
-        /* We don't have a way of forcing this to use a particular protocol,
-           so we always do it via protocol v2.  But if the above worked with
-           protocol v1, and this wrapper works with v2, everything should have
-           gotten tested. */
+        /*
+         * We don't have a way of forcing this to use a particular protocol,
+         * so we always do it via protocol v2.  But if the above worked with
+         * protocol v1, and this wrapper works with v2, everything should have
+         * gotten tested.
+         */
         result = remctl("localhost", 14444, principal, test);
         ok(n++, result != NULL);
         ok_int(n++, 0, result->status);
