@@ -1,13 +1,18 @@
-/*  $Id: cmd-background.c 3089 2007-03-16 08:15:06Z rra $
-**
-**  Small C program that outputs a string, forks off a process that sleeps for
-**  ten seconds and outputs another string, and meanwhile immediately exits.
-**  Used to test that remctld stops listening as soon as its child has exited
-**  and doesn't wait forever for output to be closed.
-*/
+/* $Id: cmd-background.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Small C program that outputs a string, forks off a process that sleeps for
+ * ten seconds and outputs another string, and meanwhile immediately exits.
+ * Used to test that remctld stops listening as soon as its child has exited
+ * and doesn't wait forever for output to be closed.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2007 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 
 int
 main(void)
