@@ -1,13 +1,20 @@
-/*  $Id: cmd-streaming.c 2672 2006-08-08 03:01:11Z rra $
-**
-**  Small C program to output three lines, one to stdout, one to stderr, and
-**  then one to stdout again.  Used to test remctl streaming support.
-*/
+/* $Id: cmd-streaming.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Small C program to output three lines, one to stdout, one to stderr, and
+ * then one to stdout again.  Used to test remctl streaming support.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 
-#include <sys/select.h>
+#ifdef HAVE_SYS_SELECT_H
+# include <sys/select.h>
+#endif
 #include <sys/time.h>
 
 int
