@@ -1,35 +1,37 @@
-/* $Id: inet_aton-t.c 2917 2007-01-17 19:10:48Z rra $ */
-/* inet_aton test suite. */
-
-/* Copyright (c) 2004, 2005, 2006, 2007
-       by Internet Systems Consortium, Inc. ("ISC")
-   Copyright (c) 1991, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
-       2002, 2003 by The Internet Software Consortium and Rich Salz
-
-   This code is derived from software contributed to the Internet Software
-   Consortium by Rich Salz.
-
-   Permission to use, copy, modify, and distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
-   REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY
-   SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE. */
+/* $Id: inet_aton-t.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * inet_aton test suite.
+ *
+ * Copyright (c) 2004, 2005, 2006, 2007
+ *     by Internet Systems Consortium, Inc. ("ISC")
+ * Copyright (c) 1991, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
+ *     2002, 2003 by The Internet Software Consortium and Rich Salz
+ *
+ * This code is derived from software contributed to the Internet Software
+ * Consortium by Rich Salz.
+ *
+ * Permission to use, copy, modify, and distribute this software for any
+ * purpose with or without fee is hereby granted, provided that the above
+ * copyright notice and this permission notice appear in all copies.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS" AND ISC DISCLAIMS ALL WARRANTIES WITH
+ * REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
+ * MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL ISC BE LIABLE FOR ANY
+ * SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
+ * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
+ * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
+ * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ */
 
 #include <config.h>
-#include <system.h>
-
-#include <netinet/in.h>
+#include <portable/system.h>
+#include <portable/socket.h>
 
 #include <tests/libtest.h>
 
 int test_inet_aton(const char *, struct in_addr *);
 
+
 static void
 test_addr(int n, const char *string, unsigned long addr)
 {
@@ -46,6 +48,7 @@ test_addr(int n, const char *string, unsigned long addr)
                (unsigned long) in.s_addr);
 }
 
+
 static void
 test_fail(int n, const char *string)
 {
@@ -58,6 +61,7 @@ test_fail(int n, const char *string)
     printf("%sok %d\n", success ? "" : "not ", n);
 }
 
+
 int
 main(void)
 {
