@@ -1,17 +1,21 @@
-/* $Id: acl-t.c 3147 2007-03-25 04:41:09Z rra $ */
-/* Test suite for the server ACL checking. */
-
-/* Written by Russ Allbery <rra@stanford.edu>
-   Copyright 2007 Board of Trustees, Leland Stanford Jr. University
-   See README for licensing terms. */
+/* $Id: acl-t.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Test suite for the server ACL checking.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2007 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 
 #include <server/internal.h>
 #include <tests/libtest.h>
 #include <util/util.h>
 
+
 int
 main(void)
 {
