@@ -1,12 +1,15 @@
-/* $Id: streaming-t.c 2679 2006-08-09 15:45:17Z rra $ */
-/* Test suite for streaming data from the server. */
-
-/* Written by Russ Allbery <rra@stanford.edu>
-   Copyright 2006 Board of Trustees, Leland Stanford Jr. University
-   See README for licensing terms. */
+/* $Id: streaming-t.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Test suite for streaming data from the server.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 
 #include <signal.h>
 #include <sys/wait.h>
@@ -16,6 +19,7 @@
 #include <tests/libtest.h>
 #include <util/util.h>
 
+
 int
 main(void)
 {
