@@ -1,12 +1,15 @@
-/* $Id: version-t.c 2978 2007-02-11 03:37:08Z rra $ */
-/* Test suite for version negotiation in the server. */
-
-/* Written by Russ Allbery <rra@stanford.edu>
-   Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
-   See README for licensing terms. */
+/* $Id: version-t.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Test suite for version negotiation in the server.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 #include <portable/gssapi.h>
 
 #include <signal.h>
@@ -25,6 +28,7 @@ static const char token[] = {
     0, 0, 0, 4, 't', 'e', 's', 't'
 };
 
+
 int
 main(void)
 {
