@@ -1,32 +1,24 @@
-/* $Id: faketoken.c 2978 2007-02-11 03:37:08Z rra $ */
-/* Fake token_send and token_recv functions for testing. */
-
-/* Written by Russ Allbery <rra@stanford.edu>
-   Copyright 2006 Board of Trustees, Leland Stanford Jr. University
-   See README for licensing terms. */
+/* $Id: faketoken.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Fake token_send and token_recv functions for testing.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 
 #include <util/util.h>
 
-/* __attribute__ is available in gcc 2.5 and later, but only with gcc 2.7
-   could you use the __format__ form of the attributes, which is what we use
-   (to avoid confusion with other macros). */
-#ifndef __attribute__
-# if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 7)
-#  define __attribute__(spec)   /* empty */
-# endif
-#endif
-
-/* Used for unused parameters to silence gcc warnings. */
-#define UNUSED  __attribute__((__unused__))
-
 enum token_status fake_token_send(int, int, gss_buffer_t);
 enum token_status fake_token_recv(int, int *, gss_buffer_t, size_t);
 
-/* The token and flags are actually read from or written to these
-   variables. */
+/*
+ * The token and flags are actually read from or written to these variables.
+ */
 char send_buffer[2048];
 char recv_buffer[2048];
 size_t send_length;
@@ -34,7 +26,10 @@ size_t recv_length;
 int send_flags;
 int recv_flags;
 
-/* Accept a token write request and store it into the buffer. */
+
+/*
+ * Accept a token write request and store it into the buffer.
+ */
 enum token_status
 fake_token_send(int fd UNUSED, int flags, gss_buffer_t tok)
 {
@@ -46,7 +41,10 @@ fake_token_send(int fd UNUSED, int flags, gss_buffer_t tok)
     return TOKEN_OK;
 }
 
-/* Receive a token from the stored buffer and return it. */
+
+/*
+ * Receive a token from the stored buffer and return it.
+ */
 enum token_status
 fake_token_recv(int fd UNUSED, int *flags, gss_buffer_t tok, size_t max)
 {
