@@ -1,12 +1,15 @@
-/* $Id: gss-tokens-t.c 2978 2007-02-11 03:37:08Z rra $ */
-/* gss-tokens test suite. */
-
-/* Written by Russ Allbery <rra@stanford.edu>
-   Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
-   See README for licensing terms. */
+/* $Id: gss-tokens-t.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * gss-tokens test suite.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * Copyright 2006, 2007 Board of Trustees, Leland Stanford Jr. University
+ *
+ * See LICENSE for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 #include <portable/gssapi.h>
 
 #include <tests/libtest.h>
@@ -19,6 +22,7 @@ extern size_t recv_length;
 extern int send_flags;
 extern int recv_flags;
 
+
 int
 main(void)
 {
@@ -39,8 +43,10 @@ main(void)
         return 0;
     }
 
-    /* We have to set up a context first in order to do this test, which is
-       rather annoying. */
+    /*
+     * We have to set up a context first in order to do this test, which is
+     * rather annoying.
+     */
     name_buf.value = principal;
     name_buf.length = strlen(principal) + 1;
     s_stat = gss_import_name(&s_min_stat, &name_buf, GSS_C_NT_USER_NAME,
@@ -120,8 +126,10 @@ main(void)
                              &s_stat, &s_min_stat);
     ok_int(13, TOKEN_FAIL_GSSAPI, status);
 
-    /* Now, fake up a token to make sure that token_recv_priv is doing the
-       right thing. */
+    /*
+     * Now, fake up a token to make sure that token_recv_priv is doing the
+     * right thing.
+     */
     recv_flags = 5;
     client_tok.value = (char *) "hello";
     client_tok.length = 5;
