@@ -1,29 +1,31 @@
-/*  $Id: gss-tokens.c 2978 2007-02-11 03:37:08Z rra $
-**
-**  GSS token handling routines.
-**
-**  Higher-level wrappers around the low-level token handling routines that
-**  apply integrity and privacy protection to the token data before sending.
-**  token_send_priv and token_recv_priv are similar to token_send and
-**  token_recv except that they also take a GSS-API context and a GSS-API
-**  major and minor status to report errors.
-**
-**  Originally written by Anton Ushakov
-**  Extensive modifications by Russ Allbery <rra@stanford.edu>
-**  Copyright 2002, 2003, 2004, 2005, 2006, 2007
-**      Board of Trustees, Leland Stanford Jr. University
-**
-**  See README for licensing terms.
-*/
+/* $Id: gss-tokens.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * GSS token handling routines.
+ *
+ * Higher-level wrappers around the low-level token handling routines that
+ * apply integrity and privacy protection to the token data before sending.
+ * token_send_priv and token_recv_priv are similar to token_send and
+ * token_recv except that they also take a GSS-API context and a GSS-API major
+ * and minor status to report errors.
+ *
+ * Originally written by Anton Ushakov
+ * Extensive modifications by Russ Allbery <rra@stanford.edu>
+ * Copyright 2002, 2003, 2004, 2005, 2006, 2007, 2008
+ *     Board of Trustees, Leland Stanford Jr. University
+ *
+ * See README for licensing terms.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 #include <portable/gssapi.h>
 
 #include <util/util.h>
 
-/* If we're running the test suite, call testing versions of the token
-   functions. */
+/*
+ * If we're running the test suite, call testing versions of the token
+ * functions.
+ */
 #if TESTING
 # define token_send fake_token_send
 # define token_recv fake_token_recv
@@ -33,16 +35,16 @@ enum token_status token_recv(int, int *, gss_buffer_t, size_t);
 
 
 /*
-**  Wraps, encrypts, and sends a data payload token.  Takes the file
-**  descriptor to send to, the GSS-API context, the flags to send with the
-**  token, the token, and the status variables.  Returns TOKEN_OK on success
-**  and TOKEN_FAIL_SYSTEM or TOKEN_FAIL_GSSAPI on failure.  If the latter is
-**  returned, the major and minor status variables will be set to something
-**  useful.
-**
-**  As a hack to support remctl v1, look to see if the flags includes
-**  TOKEN_SEND_MIC and don't include TOKEN_PROTOCOL.  If so, expect the remote
-**  side to reply with a MIC, which we then verify.
+ * Wraps, encrypts, and sends a data payload token.  Takes the file descriptor
+ * to send to, the GSS-API context, the flags to send with the token, the
+ * token, and the status variables.  Returns TOKEN_OK on success and
+ * TOKEN_FAIL_SYSTEM or TOKEN_FAIL_GSSAPI on failure.  If the latter is
+ * returned, the major and minor status variables will be set to something
+ * useful.
+ *
+ * As a hack to support remctl v1, look to see if the flags includes
+ * TOKEN_SEND_MIC and don't include TOKEN_PROTOCOL.  If so, expect the remote
+ * side to reply with a MIC, which we then verify.
 */
 enum token_status
 token_send_priv(int fd, gss_ctx_id_t ctx, int flags, gss_buffer_t tok,
@@ -81,18 +83,18 @@ token_send_priv(int fd, gss_ctx_id_t ctx, int flags, gss_buffer_t tok,
 
 
 /*
-**  Receives and unwraps a data payload token.  Takes the file descriptor,
-**  GSS-API context, a pointer into which to storge the flags, a buffer for
-**  the message, and a place to put GSS-API major and minor status.  Returns
-**  TOKEN_OK on success or one of the TOKEN_FAIL_* statuses on failure.  On
-**  success, tok will contain newly allocated memory and should be freed when
-**  no longer needed using gss_release_buffer.  On failure, any allocated
-**  memory will be freed.
-**
-**  As a hack to support remctl v1, look to see if the flags includes
-**  TOKEN_SEND_MIC and do not include TOKEN_PROTOCOL.  If so, calculate a MIC
-**  and send it back.
-*/
+ * Receives and unwraps a data payload token.  Takes the file descriptor,
+ * GSS-API context, a pointer into which to storge the flags, a buffer for the
+ * message, and a place to put GSS-API major and minor status.  Returns
+ * TOKEN_OK on success or one of the TOKEN_FAIL_* statuses on failure.  On
+ * success, tok will contain newly allocated memory and should be freed when
+ * no longer needed using gss_release_buffer.  On failure, any allocated
+ * memory will be freed.
+ *
+ * As a hack to support remctl v1, look to see if the flags includes
+ * TOKEN_SEND_MIC and do not include TOKEN_PROTOCOL.  If so, calculate a MIC
+ * and send it back.
+ */
 enum token_status
 token_recv_priv(int fd, gss_ctx_id_t ctx, int *flags, gss_buffer_t tok,
                 size_t max, OM_uint32 *major, OM_uint32 *minor)
@@ -105,9 +107,9 @@ token_recv_priv(int fd, gss_ctx_id_t ctx, int *flags, gss_buffer_t tok,
     if (status != TOKEN_OK)
         return status;
     *major = gss_unwrap(minor, ctx, &in, tok, &state, NULL);
+    free(in.value);
     if (*major != GSS_S_COMPLETE)
         return TOKEN_FAIL_GSSAPI;
-    gss_release_buffer(minor, &in);
     if ((*flags & TOKEN_SEND_MIC) && !(*flags & TOKEN_PROTOCOL)) {
         *major = gss_get_mic(minor, ctx, GSS_C_QOP_DEFAULT, tok, &mic);
         if (*major != GSS_S_COMPLETE) {
