@@ -1,37 +1,38 @@
-/*  $Id: vector.c 2537 2006-04-13 00:06:06Z rra $
-**
-**  Vector handling (counted lists of char *'s).
-**
-**  Written by Russ Allbery <rra@stanford.edu>
-**  This work is hereby placed in the public domain by its author.
-**
-**  A vector is a table for handling a list of strings with less overhead than
-**  linked list.  The intention is for vectors, once allocated, to be reused;
-**  this saves on memory allocations once the array of char *'s reaches a
-**  stable size.
-**
-**  There are two types of vectors.  Standard vectors copy strings when
-**  they're inserted into the vector, whereas cvectors just accept pointers
-**  to external strings to store.  There are therefore two entry points for
-**  every vector function, one for vectors and one for cvectors.
-**
-**  There's a whole bunch of code duplication here.  This would be a lot
-**  cleaner with C++ features (either inheritance or templates would
-**  probably help).  One could probably in some places just cast a cvector
-**  to a vector and perform the same operations, but I'm leery of doing that
-**  as I'm not sure if it's a violation of the C type aliasing rules.
-*/
+/* $Id: vector.c 4022 2008-03-31 06:11:07Z rra $
+ *
+ * Vector handling (counted lists of char *'s).
+ *
+ * A vector is a table for handling a list of strings with less overhead than
+ * linked list.  The intention is for vectors, once allocated, to be reused;
+ * this saves on memory allocations once the array of char *'s reaches a
+ * stable size.
+ *
+ * There are two types of vectors.  Standard vectors copy strings when they're
+ * inserted into the vector, whereas cvectors just accept pointers to external
+ * strings to store.  There are therefore two entry points for every vector
+ * function, one for vectors and one for cvectors.
+ *
+ * There's a whole bunch of code duplication here.  This would be a lot
+ * cleaner with C++ features (either inheritance or templates would probably
+ * help).  One could probably in some places just cast a cvector to a vector
+ * and perform the same operations, but I'm leery of doing that as I'm not
+ * sure if it's a violation of the C type aliasing rules.
+ *
+ * Written by Russ Allbery <rra@stanford.edu>
+ * This work is hereby placed in the public domain by its author.
+ */
 
 #include <config.h>
-#include <system.h>
+#include <portable/system.h>
 
 #include <ctype.h>
 
 #include <util/util.h>
 
+
 /*
-**  Allocate a new, empty vector.
-*/
+ * Allocate a new, empty vector.
+ */
 struct vector *
 vector_new(void)
 {
@@ -58,8 +59,8 @@ cvector_new(void)
 
 
 /*
-**  Resize a vector (using realloc to resize the table).
-*/
+ * Resize a vector (using realloc to resize the table).
+ */
 void
 vector_resize(struct vector *vector, size_t size)
 {
@@ -96,10 +97,10 @@ cvector_resize(struct cvector *vector, size_t size)
 
 
 /*
-**  Add a new string to the vector, resizing the vector as necessary.  The
-**  vector is resized an element at a time; if a lot of resizes are expected,
-**  vector_resize should be called explicitly with a more suitable size.
-*/
+ * Add a new string to the vector, resizing the vector as necessary.  The
+ * vector is resized an element at a time; if a lot of resizes are expected,
+ * vector_resize should be called explicitly with a more suitable size.
+ */
 void
 vector_add(struct vector *vector, const char *string)
 {
@@ -124,8 +125,8 @@ cvector_add(struct cvector *vector, const char *string)
 
 
 /*
-**  Empty a vector but keep the allocated memory for the pointer table.
-*/
+ * Empty a vector but keep the allocated memory for the pointer table.
+ */
 void
 vector_clear(struct vector *vector)
 {
@@ -144,8 +145,8 @@ cvector_clear(struct cvector *vector)
 
 
 /*
-**  Free a vector completely.
-*/
+ * Free a vector completely.
+ */
 void
 vector_free(struct vector *vector)
 {
@@ -164,9 +165,9 @@ cvector_free(struct cvector *vector)
 
 
 /*
-**  Given a vector that we may be reusing, clear it out.  If the first
-**  argument is NULL, allocate a new vector.  Used by vector_split*.
-*/
+ * Given a vector that we may be reusing, clear it out.  If the first argument
+ * is NULL, allocate a new vector.  Used by vector_split*.
+ */
 static struct vector *
 vector_reuse(struct vector *vector)
 {
@@ -191,9 +192,9 @@ cvector_reuse(struct cvector *vector)
 
 
 /*
-**  Given a string and a separator character, count the number of strings
-**  that it will split into.
-*/
+ * Given a string and a separator character, count the number of strings that
+ * it will split into.
+ */
 static size_t
 split_count(const char *string, char separator)
 {
@@ -210,10 +211,10 @@ split_count(const char *string, char separator)
 
 
 /*
-**  Given a string and a separator character, form a vector by splitting the
-**  string at those separators.  Do a first pass to size the vector, and if
-**  the third argument isn't NULL, reuse it.  Otherwise, allocate a new one.
-*/
+ * Given a string and a separator character, form a vector by splitting the
+ * string at those separators.  Do a first pass to size the vector, and if the
+ * third argument isn't NULL, reuse it.  Otherwise, allocate a new one.
+ */
 struct vector *
 vector_split(const char *string, char separator, struct vector *vector)
 {
@@ -239,12 +240,12 @@ vector_split(const char *string, char separator, struct vector *vector)
 
 
 /*
-**  Given a modifiable string and a separator character, form a cvector by
-**  modifying the string in-place to add nuls at the separators and then
-**  building a vector of pointers into the string.  Do a first pass to size
-**  the vector, and if the third argument isn't NULL, reuse it.  Otherwise,
-**  allocate a new one.
-*/
+ * Given a modifiable string and a separator character, form a cvector by
+ * modifying the string in-place to add nuls at the separators and then
+ * building a vector of pointers into the string.  Do a first pass to size the
+ * vector, and if the third argument isn't NULL, reuse it.  Otherwise,
+ * allocate a new one.
+ */
 struct cvector *
 cvector_split(char *string, char separator, struct cvector *vector)
 {
@@ -271,9 +272,9 @@ cvector_split(char *string, char separator, struct cvector *vector)
 
 
 /*
-**  Given a string, count the number of strings that it will split into when
-**  splitting on whitespace.
-*/
+ * Given a string, count the number of strings that it will split into when
+ * splitting on whitespace.
+ */
 static size_t
 split_space_count(const char *string)
 {
@@ -286,8 +287,10 @@ split_space_count(const char *string)
         if ((*p == ' ' || *p == '\t') && !(p[-1] == ' ' || p[-1] == '\t'))
             count++;
 
-    /* If the string ends in whitespace, we've overestimated the number of
-       strings by one. */
+    /*
+     * If the string ends in whitespace, we've overestimated the number of
+     * strings by one.
+     */
     if (p[-1] == ' ' || p[-1] == '\t')
         count--;
     return count;
@@ -295,11 +298,11 @@ split_space_count(const char *string)
 
 
 /*
-**  Given a string, split it at whitespace to form a vector, copying each
-**  string segment.  If the fourth argument isn't NULL, reuse that vector;
-**  otherwise, allocate a new one.  Any number of consecutive whitespace
-**  characters is considered a single separator.
-*/
+ * Given a string, split it at whitespace to form a vector, copying each
+ * string segment.  If the fourth argument isn't NULL, reuse that vector;
+ * otherwise, allocate a new one.  Any number of consecutive whitespace
+ * characters is considered a single separator.
+ */
 struct vector *
 vector_split_space(const char *string, struct vector *vector)
 {
@@ -327,12 +330,11 @@ vector_split_space(const char *string, struct vector *vector)
 
 
 /*
-**  Given a string, split it at whitespace to form a vector, destructively
-**  modifying the string to nul-terminate each segment.  If the fourth
-**  argument isn't NULL, reuse that vector; otherwise, allocate a new one.
-**  Any number of consecutive whitespace characters is considered a single
-**  separator.
-*/
+ * Given a string, split it at whitespace to form a vector, destructively
+ * modifying the string to nul-terminate each segment.  If the fourth argument
+ * isn't NULL, reuse that vector; otherwise, allocate a new one.  Any number
+ * of consecutive whitespace characters is considered a single separator.
+ */
 struct cvector *
 cvector_split_space(char *string, struct cvector *vector)
 {
@@ -362,10 +364,10 @@ cvector_split_space(char *string, struct cvector *vector)
 
 
 /*
-**  Given a vector and a separator string, allocate and build a new string
-**  composed of all the strings in the vector separated from each other by the
-**  seperator string.  Caller is responsible for freeing.
-*/
+ * Given a vector and a separator string, allocate and build a new string
+ * composed of all the strings in the vector separated from each other by the
+ * seperator string.  Caller is responsible for freeing.
+ */
 char *
 vector_join(const struct vector *vector, const char *seperator)
 {
@@ -410,10 +412,10 @@ cvector_join(const struct cvector *vector, const char *seperator)
 
 
 /*
-**  Given a vector and a path to a program, exec that program with the vector
-**  as its arguments.  This requires adding a NULL terminator to the vector
-**  and casting it appropriately.
-*/
+ * Given a vector and a path to a program, exec that program with the vector
+ * as its arguments.  This requires adding a NULL terminator to the vector and
+ * casting it appropriately.
+ */
 int
 vector_exec(const char *path, struct vector *vector)
 {
